import React from 'react';
import { mount } from 'enzyme';
import Form from 'react-form-controlled';
import Validator from './Validator';
import Alert from './Alert';

describe('Form', function () {
  it('should be able to create simple instance', function (done) {
    var value = {
      username: 'Zlatko'
    };

    var schema = {
      type: 'object',
      required: ['username', 'password'],
      properties: {
        username: {
          type: 'string',
          minLength: 2
        },
        password: {
          type: 'string',
          minLength: 2
        }
      }
    };

    var steps = 0;

    function onError(errors) {
      if (steps === 0) {
        expect(errors.length).toBe(1);
        expect(errors[0].path).toBe('password');
      }

      steps += 1;
    }

    function onSubmit(data) {
      expect(data.username).toBe('Zlatko');
      expect(data.password).toBe('test');
      expect(steps).toBe(2);
      done();
    }

    var wrapper = mount(React.createElement(
      Validator,
      { schema: schema },
      React.createElement(
        Form,
        {
          value: value,
          onSubmit: onSubmit,
          onError: onError
        },
        React.createElement('input', { name: 'username' }),
        React.createElement(Alert, { name: 'password' }),
        React.createElement('input', { name: 'password' }),
        React.createElement(
          'button',
          { type: 'submit' },
          'Submit'
        )
      )
    ));

    expect(wrapper.find('form').length).toBe(1);
    wrapper.render().find('[type="submit"]').at(0).click();

    setTimeout(function () {
      var div = wrapper.render().find('div');
      expect(div.text()).toBe('should have required property \'password\'');
      steps++;
    }, 0);

    setTimeout(function () {
      expect(wrapper.find('input').length).toBe(2);
      wrapper.find('input').last().simulate('change', { target: {
          value: 'test'
        } });

      wrapper.render().find('[type="submit"]').at(0).click();
    }, 0);
  });
});
//# sourceMappingURL=Validator.test.js.map