var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { Element } from 'react-form-controlled';

export default class Alert extends Element {

  componentDidMount() {
    const form = this.getForm();
    form.registerChild(this);
  }

  componentWillUnmount() {
    const form = this.getForm();
    form.unregisterChild(this);
  }

  originalValueChanged() {
    this.forceUpdate();
  }

  render() {
    const _props = this.props,
          { className, children, render, component: Component, exact } = _props,
          rest = _objectWithoutProperties(_props, ['className', 'children', 'render', 'component', 'exact']);
    const path = this.getPath();
    const form = this.getForm();

    const errors = form.getErrors(path, exact);
    if (!errors || !errors.length) {
      return null;
    }

    if (typeof children === 'function') {
      return this.replaceChildren(children({ errors }));
    } else if (typeof render === 'function') {
      return this.replaceChildren(render({ errors }));
    } else if (Component) {
      return React.createElement(Component, _extends({ errors: errors }, rest));
    } else if (children) {
      return children;
    }

    return React.createElement(
      'div',
      { role: 'alert', className: className },
      errors.map(error => error.message)
    );
  }
}
Alert.propTypes = {
  name: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
  exact: PropTypes.bool,
  children: PropTypes.oneOfType([PropTypes.node, PropTypes.func]),
  render: PropTypes.func,
  component: PropTypes.node,
  className: PropTypes.string
};
//# sourceMappingURL=Alert.js.map